======================
How To Install Mahotas
======================

From source
-----------

You can get the released version using your favorite Python package manager::

    easy_install mahotas

or::

    pip install mahotas

If you prefer, you can download the source from `PyPI
<http://pypi.python.org/pypi/mahotas>`__ and run::

    python setup.py install

You will need to have ``numpy`` and a ``C++`` compiler.


Bleeding Edge (Development)
~~~~~~~~~~~~~~~~~~~~~~~~~~~

Development happens on `github <https://github.com/luispedro/mahotas>`__. You
can get the development source there. Watch out that *these versions are more
likely to have problems*.

On Windows
----------

On Windows, Christoph Gohlke does an excelent job maintaining `binary packages
of mahotas <http://www.lfd.uci.edu/~gohlke/pythonlibs/>`__ (and several other
packages).

Packaged Versions
-----------------

Python(x, y)
~~~~~~~~~~~~

If you use `Python(x, y) <http://pythonxy.com/>`__, which is often a good
solution, you can find mahotas in the `Additional Plugins
<http://code.google.com/p/pythonxy/wiki/AdditionalPlugins>`__ page.

FreeBSD
~~~~~~~

Mahotas is available for FreeBSD as `graphics/mahotas
<http://www.freshports.org/graphics/mahotas>`__.

MacPorts
~~~~~~~~

For Macports, mahotas is available as `py27-mahotas
<https://trac.macports.org/browser/trunk/dports/python/py-mahotas/Portfile>`__.

Frugalware Linux
~~~~~~~~~~~~~~~~

Mahotas is available as ``python-mahotas``.

